#!/bin/bash

# SPDX-FileCopyrightText: none
#
# SPDX-License-Identifier: CC0-1.0

die()
{
    echo "$@" >&2
    exit 1
}

version="@VERSION@"
qt="/home/tobias/Qt/6.8.3_static"

# Prepare the translations
$qt/bin/lconvert -o qtbase_de.qm $qt/translations/qtbase_de.qm || die
$qt/bin/lrelease ../muckturnier_de.ts -qm muckturnier_de.qm || die

# Build Muckturnier
mkdir -p build || die
cd build || die
$qt/bin/qmake ../muckturnier.pro -config release || die
make -j$(nproc) || die
strip muckturnier || die
cp muckturnier ../ || die
cd .. || die

# Prepare an AppDir with our resources
mkdir -p AppDir/usr/ || die
cp -r share AppDir/usr/ || die
cp *.qm AppDir/usr/share/muckturnier/ || die
mkdir -p AppDir/usr/share/metainfo/ || die
cp ../org.muckturnier.muckturnier.appdata.xml AppDir/usr/share/metainfo/ || die

# Build the AppImage
linuxdeploy \
    --appdir AppDir \
    --executable muckturnier \
    --desktop-file ../org.muckturnier.muckturnier.desktop \
    --icon-file AppDir/usr/share/icons/hicolor/128x128/apps/muckturnier.png \
    --output appimage || die

cp Muckturnier-x86_64.AppImage ../../../Muckturnier-$version-x86_64.AppImage || die
