#!/usr/bin/env python3

# SPDX-FileCopyrightText: 2025 Tobias Leupold <tl@stonemx.de>
#
# SPDX-License-Identifier: BSD-2-Clause

from urllib import request
from json import loads as parseJson
import os
import sys

print("Checking latest linuxdeploy version ...")

project = "linuxdeploy/linuxdeploy"
githubLatest = "https://api.github.com/repos/{}/releases/latest"

with request.urlopen(githubLatest.format(project)) as response:
   json = parseJson(response.read())

tagName = json["tag_name"]

for asset in json["assets"]:
    if not "x86_64" in asset["name"]:
        continue

    fileName = asset["name"]
    downloadUrl = asset["browser_download_url"]
    break

print("The lastest version is {}".format(tagName))

versionedFileName = fileName.replace("linuxdeploy-", "linuxdeploy-{}-".format(tagName))

try:
    currentLink = os.readlink("linuxdeploy")
except:
    currentLink = ""

if (currentLink == versionedFileName):
    print("Already up to date")
    sys.exit(0)

if currentLink:
    os.remove(currentLink)
    os.unlink("linuxdeploy")

print("Downloading {} ...".format(fileName))

chunkSize = 1024
with request.urlopen(downloadUrl) as response:
    contentLength = int(response.getheader("Content-Length"))

    with open(versionedFileName, "wb") as out_file:
        downloaded = 0
        while True:
            chunk = response.read(chunkSize)
            if not chunk: # EOF
                break

            out_file.write(chunk)
            downloaded += len(chunk)

            print("    {}/{} Bytes retrieved ({} %)".format( \
                contentLength, downloaded, int(downloaded / contentLength * 100.0)), end = "\r")

print("\nDownload finished")

os.chmod(versionedFileName, 0o777)
os.symlink(versionedFileName, "linuxdeploy")

print("linuxdeploy now points to version {}.".format(tagName))
