// SPDX-FileCopyrightText: 2024-2025 Tobias Leupold <tl@stonemx.de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes

#include "Application.h"

#include "SplashButton.h"

#include "SharedObjects/ResourceFinder.h"

SplashButton::SplashButton(const QString &text, const QString &icon, ResourceFinder *resourceFinder,
                           QWidget *parent)
    : QToolButton(parent),
      m_resourceFinder(resourceFinder),
      m_icon(icon)
{
    setProperty("splashButton", true);

    setAutoRaise(true);
    setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
    setIconSize(QSize(100, 100));
    setText(text);

    initializeIcon();
    connect(qobject_cast<Application *>(qApp), &Application::paletteChanged,
            this, &SplashButton::initializeIcon);
}

void SplashButton::initializeIcon()
{
    setIcon(QIcon(m_resourceFinder->find(m_icon)));
}
