// SPDX-FileCopyrightText: 2019-2025 Tobias Leupold <tl@stonemx.de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes

#include "MarkerPopup.h"

#include "shared/PopupButton.h"

// Qt includes
#include <QDebug>
#include <QVBoxLayout>
#include <QPushButton>
#include <QVariant>
#include <QLabel>

// C++ includes
#include <functional>

MarkerPopup::MarkerPopup(QWidget *parent, const QVector<Markers::Marker> &markers)
    : SelectionPopup(parent)
{
    auto *widget = new QWidget;
    auto *layout = new QVBoxLayout(widget);
    layout->setSpacing(0);
    layout->setContentsMargins(10, 2, 12, 0);

    for (const Markers::Marker &marker : markers) {
        auto *button = new PopupButton(marker.name);
        button->setProperty("id", QVariant(marker.id));
        button->setColor(marker.color);
        layout->addWidget(button);
        connect(button, &QPushButton::clicked, this,
                std::bind(&MarkerPopup::requestSetMarker, this, marker.id));
        connect(button, &QPushButton::clicked, this, &QDialog::accept);
    }

    if (markers.count() == 1) {
        auto *label = new QLabel(tr("<i>Es wurden bisher keine<br/>Markierungen definiert</i>"));
        label->setAlignment(Qt::AlignCenter);
        layout->addWidget(label);
    }

    setScrollWidget(widget);
}

void MarkerPopup::show(int currentMarker, const QPoint &position)
{
    // Hide the current marker
    for (auto *button : findChildren<QPushButton *>()) {
        button->setVisible(button->property("id").toInt() != currentMarker);
    }

    if (position == QPoint(-1, -1)) {
        SelectionPopup::show();
    } else {
        SelectionPopup::show(position);
    }
}
