// SPDX-FileCopyrightText: 2017-2025 Tobias Leupold <tl@stonemx.de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "TimeLabel.h"

// Qt includes
#include <QDebug>

static const QLatin1Char s_zero('0');
static const QLatin1Char s_colon(':');

TimeLabel::TimeLabel(QWidget *parent) : ExpandingLabel(parent)
{
    m_redText.setColor(QPalette::WindowText, Qt::red);

    QFont labelFont;
    labelFont.setBold(true);
    setFont(labelFont);
}

void TimeLabel::setSeconds(qint64 seconds)
{
    if (seconds < 0 && ! m_displayIsRed) {
        setPalette(m_redText);
        m_displayIsRed = true;
    }
    if (seconds >= 0 && m_displayIsRed) {
        setPalette(m_normalText);
        m_displayIsRed = false;
    }

    m_seconds = seconds;
    qint64 secondsLeft = seconds;
    qint64 displaySeconds = abs(secondsLeft % 60);
    secondsLeft /= 60;
    qint64 minutes = abs(secondsLeft % 60);
    secondsLeft /= 60;
    qint64 hours = abs(secondsLeft);

    setText((m_displayIsRed ? tr("-") : QString())
            +           QString::number(hours         ).rightJustified(2, s_zero)
            + s_colon + QString::number(minutes       ).rightJustified(2, s_zero)
            + s_colon + QString::number(displaySeconds).rightJustified(2, s_zero));
}

qint64 TimeLabel::seconds() const
{
    return m_seconds;
}
