// SPDX-FileCopyrightText: 2018-2025 Tobias Leupold <tl@stonemx.de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes

#include "ScorePopup.h"

#include "shared/PopupButton.h"

// Qt includes
#include <QDebug>
#include <QGridLayout>

ScorePopup::ScorePopup(QWidget *parent, int boogerScore)
    : SelectionPopup(parent)
{
    // We want square buttons. We cache the edgeLength length here:
    const auto dummyButton = PopupButton();
    const QFontMetrics fontMetrics(font());
    const int edgeLength = dummyButton.sizeHint().height() + fontMetrics.height() * 0.3;

    auto *widget = new QWidget;
    auto *layout = new QGridLayout(widget);

    int maximumColumns;
    if (boogerScore <= 31) {
        maximumColumns = 5;
    } else {
        maximumColumns = 10;
    }

    int row = -1;
    int score = -1;
    bool finished = false;

    while (! finished) {
        row++;
        for (int column = 0; column < maximumColumns; column++) {
            score++;
            if (score == boogerScore) {
                finished = true;
                break;
            }

            auto *button = new PopupButton(QString::number(score));
            button->setFixedSize(edgeLength, edgeLength);

            layout->addWidget(button, row, column);

            connect(button, &QPushButton::clicked,
                    this, [this, button, score]
                    {
                        // This prevent the button to be highlighted afterwards on Windows
                        button->clearFocus();
                        Q_EMIT requestSetScore(score, m_targetSpinBox);
                        accept();
                    });
        }
    }

    setScrollWidget(widget);
}

void ScorePopup::show(BoogerSpinBox *targetSpinBox)
{
    m_targetSpinBox = targetSpinBox;
    SelectionPopup::show();
}
