// SPDX-FileCopyrightText: 2020-2025 Tobias Leupold <tl@stonemx.de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "ScoreWidget.h"
#include "BoogerWidget.h"

// Qt includes
#include <QPushButton>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QGridLayout>
#include <QLabel>
#include <QDebug>
#include <QStyle>

ScoreWidget::ScoreWidget(Tournament::ScoreType scoreType,
                         const QVector<BoogerWidget *> &boogerWidgets,
                         QPushButton *saveScore, QWidget *parent)
    : MinimumViewportWidget(parent)
{
    switch (scoreType) {

    case Tournament::HorizontalScore: {
        QHBoxLayout *layout = new QHBoxLayout(this);
        layout->setContentsMargins(0, 0, 0, 0);

        for (BoogerWidget *boogerWidget : boogerWidgets) {
            layout->addWidget(boogerWidget);
        }

        layout->addWidget(saveScore);

        setMinimumViewport(sizeHint());

        } break;

    case Tournament::VerticalScore: {
        QHBoxLayout *layout = new QHBoxLayout(this);
        layout->setContentsMargins(0, 0, 0, 0);

        QGridLayout *boogerLayout = new QGridLayout;
        layout->addLayout(boogerLayout);

        QFont headerFont;
        headerFont.setBold(true);

        const auto multipleBoogers = boogerWidgets.size() > 1;
        int i = 0;
        for (BoogerWidget *boogerWidget : boogerWidgets) {
            QLabel *boogerHeader;
            if (multipleBoogers) {
                boogerHeader = new QLabel(tr("%1. Bobbl").arg(++i));
            } else {
                i++;
                boogerHeader = new QLabel(tr("Ergebnis"));
            }
            boogerHeader->setFont(headerFont);
            boogerLayout->addWidget(boogerHeader, i - 1, 0);
            boogerLayout->addWidget(boogerWidget, i - 1, 1);
        }

        QVBoxLayout *saveLayout = new QVBoxLayout;
        saveLayout->setAlignment(Qt::AlignBottom);
        layout->addLayout(saveLayout);
        saveLayout->addWidget(saveScore);

        const int count = boogerWidgets.count();
        const QSize hint = sizeHint();
        setMinimumViewport(QSize(hint.width(), hint.height() / count * (count == 1 ? 1 : 2)));

        } break;

    }
}
