// SPDX-FileCopyrightText: 2025 Tobias Leupold <tl@stonemx.de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "ReadyToScanLabel.h"
#include "ScanLineEdit.h"

// Qt includes
#include <QApplication>

ReadyToScanLabel::ReadyToScanLabel(ScanLineEdit *scanLineEdit, QWidget *parent)
    : QLabel(parent),
      m_scanLineEdit(scanLineEdit)
{
    m_greenText.setColor(QPalette::WindowText, QColor(0, 150, 0));
    m_darkGreenText.setColor(QPalette::WindowText, QColor(0, 190, 0));

    updateText();
    connect(m_scanLineEdit, &ScanLineEdit::focusChanged, this, &ReadyToScanLabel::updateText);
    connect(m_scanLineEdit, &QLineEdit::textChanged, this, &ReadyToScanLabel::updateText);
}

void ReadyToScanLabel::updateText()
{
    if (m_scanLineEdit->readyToScan()) {
        setText(tr("Bereit zum Scannen"));
        setPalette(qApp->property("DARK_MODE").toBool() ? m_darkGreenText : m_greenText);
    } else {
        setText(tr("Nicht bereit zum Scannen"));
        setPalette(m_normalText);
    }
}
