// SPDX-FileCopyrightText: 2023-2025 Tobias Leupold <tl@stonemx.de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "WatchingSplitter.h"

// Qt includes
#include <QDebug>
#include <QEvent>
#include <QScrollBar>

// Helper QObject to monitor visibility changes of a QScrollBar

VisibilityWatcher::VisibilityWatcher(QObject *parent) : QObject(parent)
{
}

bool VisibilityWatcher::eventFilter(QObject *object, QEvent *event)
{
    const auto type = event->type();
    if (type == QEvent::Show && ! m_isVisible) {
        m_isVisible = true;
        Q_EMIT visibilityChanged(true);
    } else if (type == QEvent::Hide && m_isVisible) {
        m_isVisible = false;
        Q_EMIT visibilityChanged(false);
    }

    // Do the standard event processing
    return QObject::eventFilter(object, event);
}

// The splitter subclass itself

WatchingSplitter::WatchingSplitter(Qt::Orientation orientation, QWidget *parent)
    : QSplitter(orientation, parent)
{
}

void WatchingSplitter::initializeHandle()
{
    if (m_scrollBar == nullptr) {
        return;
    }

    setProperty("notNeeded", ! m_scrollBar->isVisible());
}

void WatchingSplitter::watchScrollBar(QScrollBar *scrollBar)
{
    m_scrollBar = scrollBar;

    auto *visibilityWatcher = new VisibilityWatcher(this);
    m_scrollBar->installEventFilter(visibilityWatcher);
    connect(visibilityWatcher, &VisibilityWatcher::visibilityChanged,
            this, [this](bool isVisible)
            {
                setProperty("notNeeded", ! isVisible);
            });
}
