// SPDX-FileCopyrightText: 2023-2025 Tobias Leupold <tl@stonemx.de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef WATCHINGSPLITTER_H
#define WATCHINGSPLITTER_H

// Qt includes
#include <QSplitter>

// Qt classes
class QScrollBar;

// Helper QObject to monitor visibility changes of a QScrollBar

class VisibilityWatcher : public QObject
{
    Q_OBJECT

public:
    explicit VisibilityWatcher(QObject *parent);

Q_SIGNALS:
    void visibilityChanged(bool isVisible);

protected:
    bool eventFilter(QObject *object, QEvent *event) override;

private: // Variables
    bool m_isVisible = false;

};

// The splitter subclass itself

class WatchingSplitter : public QSplitter
{
    Q_OBJECT

public:
    explicit WatchingSplitter(Qt::Orientation orientation, QWidget *parent = nullptr);
    void watchScrollBar(QScrollBar *scrollBar);

public Q_SLOTS:
    void initializeHandle();

private: // Variables
    QScrollBar *m_scrollBar = nullptr;

};

#endif // WATCHINGSPLITTER_H
